SWDEV-470698 - fix formatting, add format check workflow (#657)

This commit is contained in:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
committed by GitHub
parent 5840940caa
commit f7338717ae
1574 changed files with 162972 additions and 199346 deletions
+13 -13
View File
@@ -22,21 +22,21 @@
#include "hipMalloc.h"
int MallocFunc() {
int* Ad;
hipError_t err;
err = hipMalloc(reinterpret_cast<void**>(&Ad), 1024);
int* Ad;
hipError_t err;
err = hipMalloc(reinterpret_cast<void**>(&Ad), 1024);
if (err == hipSuccess) {
std::cout << "hipMalloc PASSED!" << std::endl;
err = hipFree(Ad);
if (err == hipSuccess) {
std::cout <<"hipMalloc PASSED!" <<std::endl;
err = hipFree(Ad);
if (err == hipSuccess) {
std::cout <<"hipFree PASSED!" <<std::endl;
return 1;
} else {
std::cout <<"hipFree FAILED!" <<std::endl;
return 0;
}
std::cout << "hipFree PASSED!" << std::endl;
return 1;
} else {
std::cout <<"hipMalloc FAILED!" <<std::endl;
std::cout << "hipFree FAILED!" << std::endl;
return 0;
}
} else {
std::cout << "hipMalloc FAILED!" << std::endl;
return 0;
}
}